@@ -1,14 +1,7 @@
 #pragma once
-#include<boost/python.hpp>
-#include<boost/foreach.hpp>
-#include<string>
 #include<yade/lib/base/openmp-accu.hpp>
 #include<yade/lib/serialization/Serializable.hpp>
 
-#ifndef FOREACH
-	#define FOREACH BOOST_FOREACH
-#endif
-
 namespace py=boost::python;
 
 class EnergyTracker: public Serializable{
@@ -45,10 +38,15 @@ class EnergyTracker: public Serializable{
 	void clear(){ energies.clear(); names.clear(); resetStep.clear();}
 	void resetResettables(){ size_t sz=energies.size(); for(size_t id=0; id<sz; id++){ if(resetStep[id]) energies.reset(id); } }
 
-	Real total() const;
-	py::list keys_py() const;
-	py::list items_py() const;
-	py::dict perThreadData() const;
+	Real total() const { Real ret=0; size_t sz=energies.size(); for(size_t id=0; id<sz; id++) ret+=energies.get(id); return ret; };
+	py::list keys_py() const { py::list ret; FOREACH(pairStringInt p, names) ret.append(p.first); return ret; };
+	py::list items_py() const { py::list ret; FOREACH(pairStringInt p, names) ret.append(py::make_tuple(p.first,energies.get(p.second))); return ret; };
+	py::dict perThreadData() const {
+		py::dict ret;
+		std::vector<std::vector<Real> > dta=energies.getPerThreadData();
+		FOREACH(pairStringInt p,names) ret[p.first]=dta[p.second];
+		return ret;
+  };
 
 	typedef std::map<std::string,int> mapStringInt;
 	typedef std::pair<std::string,int> pairStringInt;
