@@ -14,16 +14,12 @@
 #include<yade/core/Omega.hpp>
 #include<yade/core/Timing.hpp>
 #include<yade/lib/base/Logging.hpp>
-#include<stdexcept>
-
-#include<boost/foreach.hpp>
-#ifndef FOREACH
-#define FOREACH BOOST_FOREACH
-#endif
 
 class Body;
 class Scene;
 
+CREATE_LOGGER(Engine);
+
 class Engine: public Serializable{
 	public:
 		// pointer to the simulation, set at every step by Scene::moveToNextTimeStep
@@ -35,14 +31,17 @@ class Engine: public Serializable{
 		virtual ~Engine() {};
 	
 		virtual bool isActivated() { return true; };
-		virtual void action();
+		virtual void action() {
+			LOG_FATAL("Engine "<<getClassName()<<" calling virtual method Engine::action(). Please submit bug report at http://bugs.launchpad.net/yade.");
+			throw std::logic_error("Engine::action() called.");
+		}
 	private:
 		// py access funcs	
 		TimingInfo::delta timingInfo_nsec_get(){return timingInfo.nsec;};
 		void timingInfo_nsec_set(TimingInfo::delta d){ timingInfo.nsec=d;}
 		long timingInfo_nExec_get(){return timingInfo.nExec;};
 		void timingInfo_nExec_set(long d){ timingInfo.nExec=d;}
-		void explicitAction(); 
+		void explicitAction() {scene=Omega::instance().getScene().get(); action();}; 
 
 	DECLARE_LOGGER;
 
