@@ -15,8 +15,8 @@
 class FrontEnd : public Factorable
 {	
 	public :
-		FrontEnd ();
-		virtual ~FrontEnd ();
+		FrontEnd () {};
+		virtual ~FrontEnd () {};
 
 		virtual int run(int , char * []) { return -1;};
 		// called before actually invoking it
