@@ -14,7 +14,6 @@
 #include<yade/core/TimeStepper.hpp>
 
 #include<yade/lib/base/Math.hpp>
-#include<boost/foreach.hpp>
 #include<boost/date_time/posix_time/posix_time.hpp>
 #include<boost/algorithm/string.hpp>
 
@@ -194,8 +193,8 @@ void Scene::updateBound(){
 		if(!b) continue;
 		if(b->bound){
 			for(int i=0; i<3; i++){
-				if(!isinf(b->bound->max[i])) mx[i]=max(mx[i],b->bound->max[i]);
-				if(!isinf(b->bound->min[i])) mn[i]=min(mn[i],b->bound->min[i]);
+				if(!std::isinf(b->bound->max[i])) mx[i]=max(mx[i],b->bound->max[i]);
+				if(!std::isinf(b->bound->min[i])) mn[i]=min(mn[i],b->bound->min[i]);
 			}
 		} else {
 	 		mx=mx.cwiseMax(b->state->pos);
