@@ -26,7 +26,7 @@ namespace CGT {
 struct Boundary
 {
 	Point p;//position
-	Vecteur normal;//orientation
+	CVector normal;//orientation
 	Vector3r velocity;//motion
 	int coordinate;//the axis perpendicular to the boundary
 	bool flowCondition;//flowCondition=0, pressure is imposed // flowCondition=1, flow is imposed
@@ -46,48 +46,48 @@ class Network
 		
 		Tesselation T [2];
 		bool currentTes;
-		double x_min, x_max, y_min, y_max, z_min, z_max, Rmoy, SectionArea, Height, Vtotale;
-		bool DEBUG_OUT;
+		Tesselation& tesselation() {return T[currentTes];};
+		
+		double xMin, xMax, yMin, yMax, zMin, zMax, Rmoy, sectionArea, Height, vTotal;
+		bool debugOut;
 		int nOfSpheres;
-		int x_min_id, x_max_id, y_min_id, y_max_id, z_min_id, z_max_id;
+		int xMinId, xMaxId, yMinId, yMaxId, zMinId, zMaxId;
 		int* boundsIds [6];
-		vector<Cell_handle> boundingCells [6];
-		Point Corner_min;
-		Point Corner_max;
-		Real Vsolid_tot, Vtotalissimo, Vporale, Ssolid_tot, V_porale_porosity, V_totale_porosity;
+		vector<CellHandle> boundingCells [6];
+		Point cornerMin;
+		Point cornerMax;
+		Real VSolidTot, Vtotalissimo, vPoral, sSolidTot, vPoralPorosity, vTotalPorosity;
 		Boundary boundaries [6];
-		Boundary& boundary (int b) {return boundaries[b-id_offset];}
-		short id_offset;
-		int vtk_infinite_vertices, vtk_infinite_cells, num_particles;
+		Boundary& boundary (int b) {return boundaries[b-idOffset];}
+		short idOffset;
+		int vtkInfiniteVertices, vtkInfiniteCells, num_particles;
 
-		void AddBoundingPlanes();
-		void AddBoundingPlane (Vecteur Normal, int id_wall);
-		void AddBoundingPlane (Real center[3], double thickness, Vecteur Normal, int id_wall );
+		void addBoundingPlanes();
+		void addBoundingPlane (CVector Normal, int id_wall);
+		void addBoundingPlane (Real center[3], double thickness, CVector Normal, int id_wall );
 
-		void Define_fictious_cells( );
-		int detectFacetFictiousVertices (Cell_handle& cell, int& j);
-		double volumeSolidPore (const Cell_handle& cell);
-		double volume_single_fictious_pore(const Vertex_handle& SV1, const Vertex_handle& SV2, const Vertex_handle& SV3, const Point& PV1,  const Point& PV2, Vecteur& facetSurface);
-		double volume_double_fictious_pore(const Vertex_handle& SV1, const Vertex_handle& SV2, const Vertex_handle& SV3, const Point& PV1, const Point& PV2, Vecteur& facetSurface);
-		double spherical_triangle_volume(const Sphere& ST1, const Point& PT1, const Point& PT2, const Point& PT3);
+		void defineFictiousCells( );
+		int detectFacetFictiousVertices (CellHandle& cell, int& j);
+		double volumeSolidPore (const CellHandle& cell);
+		double volumeSingleFictiousPore(const VertexHandle& SV1, const VertexHandle& SV2, const VertexHandle& SV3, const Point& PV1,  const Point& PV2, CVector& facetSurface);
+		double volumeDoubleFictiousPore(const VertexHandle& SV1, const VertexHandle& SV2, const VertexHandle& SV3, const Point& PV1, const Point& PV2, CVector& facetSurface);
+		double sphericalTriangleVolume(const Sphere& ST1, const Point& PT1, const Point& PT2, const Point& PT3);
 		
-		double fast_spherical_triangle_area(const Sphere& STA1, const Point& STA2, const Point& STA3, const Point& PTA1);
-		Real fast_solid_angle(const Point& STA1, const Point& PTA1, const Point& PTA2, const Point& PTA3);
-		double volume_double_fictious_pore(Vertex_handle SV1, Vertex_handle SV2, Vertex_handle SV3, Point PV1);
-		double volume_single_fictious_pore(Vertex_handle SV1, Vertex_handle SV2, Vertex_handle SV3, Point PV1);
-		double Volume_Pore_VoronoiFraction ( Cell_handle& cell, int& j, bool reuseFacetData=false);
-		double Surface_Solid_Pore( Cell_handle cell, int j, bool SLIP_ON_LATERALS, bool reuseFacetData=false);
-		double spherical_triangle_area ( Sphere STA1, Sphere STA2, Sphere STA3, Point PTA1 );
+		double fastSphericalTriangleArea(const Sphere& STA1, const Point& STA2, const Point& STA3, const Point& PTA1);
+		Real fastSolidAngle(const Point& STA1, const Point& PTA1, const Point& PTA2, const Point& PTA3);
+		double volumeDoubleFictiousPore(VertexHandle SV1, VertexHandle SV2, VertexHandle SV3, Point PV1);
+		double volumeSingleFictiousPore(VertexHandle SV1, VertexHandle SV2, VertexHandle SV3, Point PV1);
+		double volumePoreVoronoiFraction ( CellHandle& cell, int& j, bool reuseFacetData=false);
+		double surfaceSolidPore( CellHandle cell, int j, bool slipBoundary, bool reuseFacetData=false);
+		double sphericalTriangleArea ( Sphere STA1, Sphere STA2, Sphere STA3, Point PTA1 );
 		
-		Vecteur surface_double_fictious_facet(Vertex_handle fSV1, Vertex_handle fSV2, Vertex_handle SV3);
-		Vecteur surface_single_fictious_facet(Vertex_handle fSV1, Vertex_handle SV2, Vertex_handle SV3);
-		double surface_solid_double_fictious_facet(Vertex_handle SV1, Vertex_handle SV2, Vertex_handle SV3);
-		double surface_solid_facet(Sphere ST1, Sphere ST2, Sphere ST3);
+		CVector surfaceDoubleFictiousFacet(VertexHandle fSV1, VertexHandle fSV2, VertexHandle SV3);
+		CVector surfaceSingleFictiousFacet(VertexHandle fSV1, VertexHandle SV2, VertexHandle SV3);
+		double surfaceSolidDoubleFictiousFacet(VertexHandle SV1, VertexHandle SV2, VertexHandle SV3);
+		double surfaceSolidFacet(Sphere ST1, Sphere ST2, Sphere ST3);
 
 		int facetF1, facetF2, facetRe1, facetRe2, facetRe3;
-		int F1, F2, Re1, Re2;
 		int facetNFictious;
-		int real_vertex;
 		double FAR;
 		static const double ONE_THIRD;
 		static const int facetVertices [4][3];
@@ -99,6 +99,4 @@ class Network
 
 #include "Network.ipp"
 
-
-
 #endif //FLOW_ENGINE
