@@ -18,11 +18,9 @@ as Bound::{min,max} might move here one day.
 */
 class Aabb : public Bound{
 	public :
-		virtual ~Aabb();
+		virtual ~Aabb() {};
 	
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(Aabb,Bound,"Axis-aligned bounding box, for use with :yref:`InsertionSortCollider`. (This class is quasi-redundant since min,max are already contained in :yref:`Bound` itself. That might change at some point, though.)",/*attrs*/,/*ctor*/createIndex(););
 	REGISTER_CLASS_INDEX(Aabb,Bound);
 };
 REGISTER_SERIALIZABLE(Aabb);
-
-
