@@ -1,7 +1,9 @@
 #pragma once
 #include<yade/core/GlobalEngine.hpp>
 class BoundaryController: public GlobalEngine{
-	virtual void action();
+	virtual void action() {
+		{ throw std::runtime_error("BoundaryController must not be used in simulations directly (BoundaryController::action called)."); }
+	}
 	YADE_CLASS_BASE_DOC(BoundaryController,GlobalEngine,"Base for engines controlling boundary conditions of simulations. Not to be used directly.");
 };
 REGISTER_SERIALIZABLE(BoundaryController);
