@@ -1,12 +1,10 @@
-#include"ParallelEngine.hpp"
-#include<boost/python.hpp>
+#include <yade/pkg/common/ParallelEngine.hpp>
+YADE_PLUGIN((ParallelEngine));
 
 #ifdef YADE_OPENMP
   #include<omp.h>
 #endif
 
-YADE_PLUGIN((ParallelEngine));
-
 //! ParallelEngine's pseudo-ctor (factory), taking nested lists of slave engines (might be moved to real ctor perhaps)
 shared_ptr<ParallelEngine> ParallelEngine_ctor_list(const boost::python::list& slaves){ shared_ptr<ParallelEngine> instance(new ParallelEngine); instance->slaves_set(slaves); return instance; }
 
