@@ -8,7 +8,7 @@ namespace yade{
 class Sphere: public Shape{
 	public:
 		Sphere(Real _radius): radius(_radius){ createIndex(); }
-		virtual ~Sphere ();
+		virtual ~Sphere () {};
 	YADE_CLASS_BASE_DOC_ATTRS_CTOR(Sphere,Shape,"Geometry of spherical particle.",
 		((Real,radius,NaN,,"Radius [m]")),
 		createIndex(); /*ctor*/
