@@ -11,8 +11,7 @@
 
 #include<yade/pkg/dem/ElasticContactLaw.hpp>
 #include <yade/pkg/dem/Law2_ScGeom_CapillaryPhys_Capillarity.hpp>
-// #include<yade/pkg/dem/Ip2_FrictMat_FrictMat_FrictPhys.hpp>
-#include<yade/pkg/dem/Ip2_FrictMat_FrictMat_CapillaryPhys.hpp>
+#include<yade/pkg/dem/CapillaryPhys.hpp>
 #include<yade/pkg/common/ElastMat.hpp>
 #include<yade/pkg/dem/GlobalStiffnessTimeStepper.hpp>
 
@@ -26,8 +25,7 @@
 #include<yade/pkg/common/InsertionSortCollider.hpp>
 #include<yade/core/Interaction.hpp>
 #include<yade/pkg/common/Dispatching.hpp>
-#include<yade/pkg/common/Bo1_Sphere_Aabb.hpp>
-#include<yade/pkg/common/Bo1_Box_Aabb.hpp>
+#include<yade/pkg/common/Bo1_Aabb.hpp>
 
 #include<yade/pkg/common/GravityEngines.hpp>
 #include<yade/pkg/dem/NewtonIntegrator.hpp>
@@ -42,8 +40,6 @@
 
 #include<yade/pkg/dem/Shop.hpp>
 
-#include <boost/filesystem/convenience.hpp>
-#include <boost/lexical_cast.hpp>
 #include <boost/numeric/conversion/bounds.hpp>
 #include <boost/limits.hpp>
 
@@ -53,8 +49,6 @@
 #include <boost/random/variate_generator.hpp>
 #include <boost/random/normal_distribution.hpp>
 
-using namespace std;
-
 typedef pair<Vector3r, Real> BasicSphere;
 //! generate a list of non-overlapping spheres
 string GenerateCloud_water(vector<BasicSphere>& sphere_list, Vector3r lowerCorner, Vector3r upperCorner, long number, Real rad_std_dev, Real porosity);
@@ -80,9 +74,9 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 	 						lowerCorner[1]-thickness/2.0,
 	 						(lowerCorner[2]+upperCorner[2])/2);
 	 	Vector3r halfSize	= Vector3r(
-	 						wallOversizeFactor*fabs(lowerCorner[0]-upperCorner[0])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[0]-upperCorner[0])/2+thickness,
 							thickness/2.0,
-	 						wallOversizeFactor*fabs(lowerCorner[2]-upperCorner[2])/2+thickness);
+	 						wallOversizeFactor*std::abs(lowerCorner[2]-upperCorner[2])/2+thickness);
 	
 		createBox(body,center,halfSize,wall_bottom_wire);
 	 	if(wall_bottom) {
@@ -98,9 +92,9 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 	 						upperCorner[1]+thickness/2.0,
 	 						(lowerCorner[2]+upperCorner[2])/2);
 	 	halfSize		= Vector3r(
-	 						wallOversizeFactor*fabs(lowerCorner[0]-upperCorner[0])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[0]-upperCorner[0])/2+thickness,
 	 						thickness/2.0,
-	 						wallOversizeFactor*fabs(lowerCorner[2]-upperCorner[2])/2+thickness);
+	 						wallOversizeFactor*std::abs(lowerCorner[2]-upperCorner[2])/2+thickness);
 	
 		createBox(body,center,halfSize,wall_top_wire);
 	 	if(wall_top) {
@@ -116,8 +110,8 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 	 						(lowerCorner[2]+upperCorner[2])/2);
 		halfSize		= Vector3r(
 							thickness/2.0,
-	 						wallOversizeFactor*fabs(lowerCorner[1]-upperCorner[1])/2+thickness,
-	 						wallOversizeFactor*fabs(lowerCorner[2]-upperCorner[2])/2+thickness);
+	 						wallOversizeFactor*std::abs(lowerCorner[1]-upperCorner[1])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[2]-upperCorner[2])/2+thickness);
 		createBox(body,center,halfSize,wall_1_wire);
 	 	if(wall_1) {
 			scene->bodies->insert(body);
@@ -131,8 +125,8 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 							(lowerCorner[2]+upperCorner[2])/2);
 	 	halfSize		= Vector3r(
 	 						thickness/2.0,
-	 						wallOversizeFactor*fabs(lowerCorner[1]-upperCorner[1])/2+thickness,
-	 						wallOversizeFactor*fabs(lowerCorner[2]-upperCorner[2])/2+thickness);
+	 						wallOversizeFactor*std::abs(lowerCorner[1]-upperCorner[1])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[2]-upperCorner[2])/2+thickness);
 	 	
 		createBox(body,center,halfSize,wall_2_wire);
 	 	if(wall_2) {
@@ -146,8 +140,8 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 	 						(lowerCorner[1]+upperCorner[1])/2,
 	 						lowerCorner[2]-thickness/2.0);
 	 	halfSize		= Vector3r(
-	 						wallOversizeFactor*fabs(lowerCorner[0]-upperCorner[0])/2+thickness,
-	 						wallOversizeFactor*fabs(lowerCorner[1]-upperCorner[1])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[0]-upperCorner[0])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[1]-upperCorner[1])/2+thickness,
 	 						thickness/2.0);
 		createBox(body,center,halfSize,wall_3_wire);
 	 	if(wall_3) {
@@ -162,8 +156,8 @@ bool CapillaryTriaxialTest::generate(std::string& message)
 	 						(lowerCorner[1]+upperCorner[1])/2,
 	 						upperCorner[2]+thickness/2.0);
 	 	halfSize		= Vector3r(
-	 						wallOversizeFactor*fabs(lowerCorner[0]-upperCorner[0])/2+thickness,
-	 						wallOversizeFactor*fabs(lowerCorner[1]-upperCorner[1])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[0]-upperCorner[0])/2+thickness,
+	 						wallOversizeFactor*std::abs(lowerCorner[1]-upperCorner[1])/2+thickness,
 	 						thickness/2.0);
 		createBox(body,center,halfSize,wall_3_wire);
 	 	if(wall_4) {
