@@ -2,11 +2,6 @@
 
 #pragma once
 
-#include<string>
-#include<map>
-#include<iostream>
-#include<typeinfo>
-#include<boost/any.hpp>
 #include<boost/lambda/lambda.hpp>
 
 #include "yade/lib/base/Math.hpp"
@@ -23,7 +18,6 @@ class ViscElMat;
 class FrictMat;
 class Interaction;
 
-using namespace std;
 using boost::shared_ptr;
 namespace py = boost::python;
 
@@ -145,7 +139,8 @@ class Shop{
 		static void setContactFriction(Real angleRad);
 
 		//! Homothetic change of sizes of spheres and clumps
-		static void growParticles(Real multiplier, bool updateMass, bool dynamicOnly, unsigned int discretization);
+		static void growParticles(Real multiplier, bool updateMass, bool dynamicOnly);
 		//! Change of size of a single sphere or a clump
+		// DEPREC, update wrt growParticles()
 		static void growParticle(Body::id_t bodyID, Real multiplier, bool updateMass);
 };
