@@ -2,28 +2,6 @@
 
 #pragma once
 
-#include<vector>
-#include<string>	
-#include<limits>
-#include<iostream>
-using namespace std; // sorry
-
-#include<boost/python.hpp>
-#include<boost/python/object.hpp>
-#include<boost/version.hpp>
-
-#include<boost/foreach.hpp>
-#ifndef FOREACH
-	#define FOREACH BOOST_FOREACH
-#endif
-
-#ifndef  __GXX_EXPERIMENTAL_CXX0X__
-#	include<boost/shared_ptr.hpp>
-	using boost::shared_ptr;
-#else
-#	include<memory>
-	using std::shared_ptr;
-#endif
 
 #include<yade/lib/base/Logging.hpp>
 #include<yade/lib/base/Math.hpp>
