@@ -1,15 +1,9 @@
 // 2008 © Václav Šmilauer <eudoxos@arcig.cz> 
 #pragma once
-#include<fstream>
-#include<limits>
 #include<yade/core/Scene.hpp>
 #include<yade/pkg/dem/Shop.hpp>
 #include<yade/pkg/common/BoundaryController.hpp>
 
-#ifndef FOREACH
-#define FOREACH BOOST_FOREACH
-#endif
-
 /*! Axial displacing two groups of bodies in the opposite direction with given strain rate.
  *
  * Takes two groups of body IDs (in posIds and negIds) and displaces them at each timestep in the direction given by axis∈{0,1,2} (for axes x,y,z respectively). These bodies automatically have Body::isDynamic==false.
