@@ -10,6 +10,7 @@
 #include<yade/pkg/common/SPHEngine.hpp>
 #endif
 
+using std::isfinite;
 YADE_PLUGIN((ViscElMat)(ViscElPhys)(Ip2_ViscElMat_ViscElMat_ViscElPhys)(Law2_ScGeom_ViscElPhys_Basic));
 
 /* ViscElMat */
@@ -28,7 +29,7 @@ void Ip2_ViscElMat_ViscElMat_ViscElPhys::go(const shared_ptr<Material>& b1, cons
 }
 
 /* Law2_ScGeom_ViscElPhys_Basic */
-void Law2_ScGeom_ViscElPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I) {
+bool Law2_ScGeom_ViscElPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I) {
 	Vector3r force = Vector3r::Zero();
 	Vector3r torque1 = Vector3r::Zero();
 	Vector3r torque2 = Vector3r::Zero();
@@ -40,11 +41,8 @@ void Law2_ScGeom_ViscElPhys_Basic::go(shared_ptr<IGeom>& _geom, shared_ptr<IPhys
 		addForce (id2, force,scene);
 		addTorque(id1, torque1,scene);
 		addTorque(id2, torque2,scene);
-		return;
-	} else {
-		scene->interactions->requestErase(I);
-		return;
-	}
+		return true;
+	} else return false;
 }
 
 bool computeForceTorqueViscEl(shared_ptr<IGeom>& _geom, shared_ptr<IPhys>& _phys, Interaction* I, Vector3r & force, Vector3r & torque1, Vector3r & torque2) {
@@ -172,7 +170,8 @@ void Ip2_ViscElMat_ViscElMat_ViscElPhys::Calculate_ViscElMat_ViscElMat_ViscElPhy
 		mass2 = mass1;
 	}
 	
-	const Real massR = 2*mass1*mass2/(mass1+mass2);
+	// See [Pournin2001, just below equation (19)]
+	const Real massR = mass1*mass2/(mass1+mass2);
 	
 	GenericSpheresContact* sphCont=YADE_CAST<GenericSpheresContact*>(interaction->geom.get());
 	Real R1=sphCont->refR1>0?sphCont->refR1:sphCont->refR2;
@@ -189,16 +188,23 @@ void Ip2_ViscElMat_ViscElMat_ViscElPhys::Calculate_ViscElMat_ViscElMat_ViscElPhy
 		const Real Tc = (tc) ? (*tc)(mat1->id,mat2->id) : (mat1->tc+mat2->tc)/2.0;
 		const Real En = (en) ? (*en)(mat1->id,mat2->id) : (mat1->en+mat2->en)/2.0;
 		const Real Et = (et) ? (*et)(mat1->id,mat2->id) : (mat1->et+mat2->et)/2.0;
-		
-		kn1 = kn2 = 1/Tc/Tc * ( Mathr::PI*Mathr::PI + pow(log(En),2) )*massR;
-		cn1 = cn2 = -2.0 /Tc * log(En)*massR;
-		ks1 = ks2 = 2.0/7.0 /Tc/Tc * ( Mathr::PI*Mathr::PI + pow(log(Et),2) )*massR;
-		cs1 = cs2 = -2.0/7.0 /Tc * log(Et)*massR;
-	
-		if (abs(cn1) <= Mathr::ZERO_TOLERANCE ) cn1=0;
-		if (abs(cn2) <= Mathr::ZERO_TOLERANCE ) cn2=0;
-		if (abs(cs1) <= Mathr::ZERO_TOLERANCE ) cs1=0;
-		if (abs(cs2) <= Mathr::ZERO_TOLERANCE ) cs2=0;
+    
+    // Factor 2 at the end of each expression is necessary, because we calculate
+    // individual kn1, kn2, ks1, ks2 etc., because kn1 = 2*kn, ks1 = 2*ks
+    // http://www.mail-archive.com/yade-users@lists.launchpad.net/msg08778.html
+    kn1 = kn2 = 1/Tc/Tc * ( Mathr::PI*Mathr::PI + pow(log(En),2) )*massR*2;
+    cn1 = cn2 = -2.0 /Tc * log(En)*massR*2;
+    ks1 = ks2 = 2.0/7.0 /Tc/Tc * ( Mathr::PI*Mathr::PI + pow(log(Et),2) )*massR*2;
+    cs1 = cs2 = -4.0/7.0 /Tc * log(Et)*massR*2;
+    //           ^^^
+    // It seems to be an error in [Pournin2001] (22) Eq.4, missing factor 2
+    // Thanks to Dominik Boemer for pointing this out
+    // http://www.mail-archive.com/yade-users@lists.launchpad.net/msg08741.html
+
+		if (std::abs(cn1) <= Mathr::ZERO_TOLERANCE ) cn1=0;
+		if (std::abs(cn2) <= Mathr::ZERO_TOLERANCE ) cn2=0;
+		if (std::abs(cs1) <= Mathr::ZERO_TOLERANCE ) cs1=0;
+		if (std::abs(cs2) <= Mathr::ZERO_TOLERANCE ) cs2=0;
 	} else if ((isfinite(mat1->kn)) and (isfinite(mat1->ks)) and (isfinite(mat1->cn)) and (isfinite(mat1->cs))) {
 		//Set parameters explicitly
 		kn1 = mat1->kn;
