@@ -26,14 +26,12 @@
 #include"HydrodynamicsLawLBM.hpp"
 #include<yade/core/Omega.hpp>
 #include<yade/core/Scene.hpp>
-#include<boost/filesystem/operations.hpp>
 #include<yade/pkg/common/Box.hpp>
 #include<yade/pkg/common/Sphere.hpp>
-#include<yade/pkg/dem/CohFrictPhys.hpp>
+#include<yade/pkg/dem/CohesiveFrictionalContactLaw.hpp>
 
 
 namespace bfs=boost::filesystem;
-using namespace std;
 
 template<class Scalar> VECTOR3_TEMPLATE(Scalar) operator*(Scalar s, const VECTOR3_TEMPLATE(Scalar)& v) {return v*s;}
 inline Vector3i vect3rToVect3i(Vector3r vect){Vector3i newvect((int)vect[0],(int)vect[1],(int)vect[2]);return(newvect);}
@@ -831,8 +829,8 @@ void HydrodynamicsLawLBM::action()
 //                for (int s=NB_WALLS ; s<NB_BODIES; s++)	{FmoyCur = FmoyCur + LBbodies[s].force.norm();}
 //                FmoyCur = FmoyCur/(NB_DYNGRAINS);
 //                if (FmoyCur!=0.){
-//                    Real ErrorA = abs(FmoyCur-FmoyPrev)/abs(FmoyCur);
-//                    Real ErrorB = abs(FmoyCur-FmoyPrevPrev)/abs(FmoyCur);
+//                    Real ErrorA = std::abs(FmoyCur-FmoyPrev)/std::abs(FmoyCur);
+//                    Real ErrorB = std::abs(FmoyCur-FmoyPrevPrev)/std::abs(FmoyCur);
 //                    Error=max(ErrorA,ErrorB);
 //                    FmoyPrevPrev=FmoyPrev;
 //                    FmoyPrev=FmoyCur;
@@ -845,8 +843,8 @@ void HydrodynamicsLawLBM::action()
 //                /*--------------------------------------------------------*/
 //                if((LBM_ITER > 100) & (LBM_ITER % 10 == 0)){
 //                if (VmeanFluidC!=0.){
-//                    Real ErrorA = abs(VmeanFluidC-PrevVmeanFluidC)/abs(VmeanFluidC);
-//                    //Real ErrorB = abs(VmeanFluidC-PrevPrevVmeanFluidC)/abs(VmeanFluidC);
+//                    Real ErrorA = std::abs(VmeanFluidC-PrevVmeanFluidC)/std::abs(VmeanFluidC);
+//                    //Real ErrorB = std::abs(VmeanFluidC-PrevPrevVmeanFluidC)/std::abs(VmeanFluidC);
 //                    //Error=max(ErrorA,ErrorB);
 //                    Error= ErrorA;
 //                    PrevPrevVmeanFluidC=PrevVmeanFluidC;
