@@ -2,21 +2,10 @@
 // the code written after http://www.amillionpixels.us/bestfitobb.cpp
 // which is MIT-licensed
 
-#include<boost/python.hpp>
-#include<boost/foreach.hpp>
-#include<boost/python/object.hpp>
-#include<boost/version.hpp>
 #include<yade/lib/base/Logging.hpp>
 #include<yade/lib/base/Math.hpp>
 #include<yade/lib/pyutil/doc_opts.hpp>
 
-#include<vector>
-#include<stdexcept>
-
-#ifndef FOREACH
-	#define FOREACH BOOST_FOREACH
-#endif
-
 // compute minimum bounding for a cloud of points
 
 // returns volume
